@@ -12,7 +12,6 @@ from dl2050nn.tabular import DataFrameProcessor
 # if regr:
 #     yrange = [df[c_dep].astype('float32').min(), df[c_dep].astype('float32').max()]
 
-
 ################################################################################################################################
 #  DataLoader
 #
@@ -35,30 +34,31 @@ def get_balanced_idxs(c_idxs, p=0.):
     z = np.random.permutation(z)
     return z.astype(int)
 
-
 def collate(b):
     x,y = zip(*b)
     return torch.stack(x),torch.stack(y)
 
 class SimpleSampler():
     def __init__(self, ds, bs):
-        self.n, self.bs = len(ds), bs
-    def set_balance(self, p): pass
+        self.n,self.bs = len(ds),bs
+    def set_balance(self, p):
+        pass
     def __iter__(self):
         self.idxs = list(range(0,self.n))
         for i in range(0, self.n, self.bs): yield self.idxs[i:i+self.bs]
 
 class RandomSampler():
-    def __init__(self, ds, bs, c_idxs): self.n, self.bs, self.c_idxs, self.p = len(ds), bs, c_idxs, None
-    def set_balance(self, p): self.p = p
+    def __init__(self, ds, bs, c_idxs):
+        self.n,self.bs,self.c_idxs,self.p = len(ds),bs,c_idxs,None
+    def set_balance(self, p):
+        self.p = p
     def __iter__(self):
-        if self.p is None:
+        if self.p is None or self.c_idxs is None:
             self.idxs = list(np.random.permutation(np.arange(self.n)))
         else:
             self.idxs = list(get_balanced_idxs(self.c_idxs, p=self.p))
         for i in range(0, self.n, self.bs): yield self.idxs[i:i+self.bs]
 
-
 class DataLoader():
     def __init__(self, ds, bs=64, shuffle=False, collate_fn=collate):
         self.ds, self.bs, self.collate_fn, self.n = ds, bs, collate_fn, len(ds)
@@ -68,7 +68,6 @@ class DataLoader():
     def __iter__(self):
         for b in self.sampler: yield self.collate_fn([self.ds[i] for i in b])
 
-
 ################################################################################################################################
 # Dataset, Data
 #
@@ -82,7 +81,7 @@ class DataLoader():
 class Dataset():
     def __init__(self, x, y, aug_size=None, clsf=False, cls_to_idx=None, cls=None, regr=False, trfs=[]):
         self.x,self.y,self.aug_size,self.clsf,self.regr,self.trfs = x,y,aug_size,clsf,regr,trfs or []
-        self.bps = None
+        self.bps,self.c_idxs = None,None
         if clsf:
             y,self.cls,self.c,self.labels,self.cls_to_idx,self.c_idxs,self.c_szs,self.c_dist = prep_cls(y, cls_to_idx=cls_to_idx, cls=cls)
             self.y = y.astype(np.int32)
