@@ -11,8 +11,10 @@ from dl2050utils.ju import in_ipynb
 from IPython.display import display
 T = torch.tensor
 
-def get_logprobs(model, x):
-    x = torch.Tensor(x).cuda()
+def get_logprobs(model, x, cuda=True):
+    x = torch.Tensor(x)
+    if cuda and torch.cuda.is_available():
+        x = x.cuda()
     with torch.no_grad():
         y2 = model(x)
     return y2.detach().cpu().numpy()
@@ -32,6 +34,12 @@ def get_preds(model, x):
     y2 = get_logprobs(model, x)
     return get_preds_from_logprobs(y2)
 
+def get_prob_positive(probs, preds):
+    probs2 = np.zeros(len(probs))
+    m = np.where(preds==1)
+    probs2[m] = probs[m]
+    return np.round(probs2,2)
+
 def predict(model, x):
     x = torch.Tensor(x).cuda()
     with torch.no_grad():
@@ -193,7 +201,7 @@ def load_model(model, path, cuda=False, inference=False, show=False):
     if show:
         pd.options.display.float_format = '{:,.4f}'.format
         display(pd.DataFrame.from_dict(stats))
-    if cuda:
+    if cuda and torch.cuda.is_available():
         model.cuda()
     if inference:
         model.eval()
