@@ -128,8 +128,9 @@ average_grad.defaults = dict(mom=0.9)
 def average_sqr_grad(state, p, sqr_mom, dampening=True, **kwargs):
     if 'sqr_avg' not in state: state['sqr_avg'] = torch.zeros_like(p.grad.data)
     damp = 1-sqr_mom if dampening else 1.
-    state['sqr_avg'].mul_(sqr_mom).addcmul_(damp, p.grad.data, p.grad.data) # -> OLD DEPRECRATED
+    # state['sqr_avg'].mul_(sqr_mom).addcmul_(damp, p.grad.data, p.grad.data) # -> OLD DEPRECRATED
     # state['sqr_avg'].mul_(sqr_mom).addcmul_(p.grad.data, p.grad.data, damp) # NEW TO BE TESTED
+    state['sqr_avg'].mul_(sqr_mom).addcmul_(p.grad.data, p.grad.data, value=damp)
     return state
 average_sqr_grad.defaults = dict(sqr_mom=0.99)
 
@@ -149,19 +150,20 @@ def weight_decay(p, lr, wd, do_wd=True, **kwargs):
 
 
 def l2_reg(p, lr, wd, do_wd=True, **kwargs):
-    if do_wd and wd!=0: p.grad.data.add_(wd, p.data)
+    if do_wd and wd!=0:
+        p.grad.data.add_(p.data, alpha=wd)
     return p
 #l2_reg.defaults = dict(wd=0.)
 
 
 def sgd_step(p, lr, **kwargs):
-    p.data.add_(-lr, p.grad.data)
+    p.data.add_(p.grad.data, alpha=-lr)
     return p
 #sgd_step._defaults = dict(lr=0.01)
 
 
 def momentum_step(p, lr, grad_avg, **kwargs):
-    p.data.add_(-lr, grad_avg)
+    p.data.add_(grad_avg, alpha=-lr)
     return p
 
 
@@ -172,7 +174,8 @@ def adam_step(p, lr, mom, step, sqr_mom, grad_avg, sqr_avg, epsilon, **kwargs):
     "Step for Adam with `lr` on `p`"
     debias1 = debias(mom, 1-mom, step)
     debias2 = debias(sqr_mom, 1-sqr_mom, step)
-    p.data.addcdiv_(-lr / debias1, grad_avg, (sqr_avg/debias2).sqrt() + epsilon)
+    # p.data.addcdiv_(-lr / debias1, grad_avg, (sqr_avg/debias2).sqrt() + epsilon)
+    p.data.addcdiv_(grad_avg, (sqr_avg/debias2).sqrt()+epsilon, value=-lr/debias1)
     return p
 #adam_step._defaults = dict(epsilon=1e-5, lr=0.01,)
 
@@ -185,7 +188,7 @@ def lamb_step(p, lr, mom, step, sqr_mom, grad_avg, sqr_avg, epsilon, **kwargs):
     step = (grad_avg/debias1) / ((sqr_avg/debias2).sqrt()+epsilon)
     r2 = step.pow(2).mean().sqrt()
     q = 1 if r1 == 0 or r2 == 0 else min(r1/r2,10)
-    p.data.add_(-lr * q, step)
+    p.data.add_(step, alpha=-lr*q)
     return p
 #lamb_step._defaults = dict(epsilon=1e-6, wd=0.)
 
